﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Diagnostics;
using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System.IO;
using WebApplication6.Models;

namespace WebApplication6.Services
{
    public class ESLPackageCreation
    {
        readonly static string CUSTOM_ID = "Signer";

        public static PackageId createPackage(FormModel model, string API_KEY, string BASE_URL)
        {
            
            String company = model.company;
            String emailAddress = model.emailAddress;
            String firstName = model.firstName;
            String lastName = model.lastName;
            String address = model.address;
            String city = model.city;
            String state = model.state;
            String zip = model.zip;
            String country = model.country;
            String phone = model.phone;
            String policyNumber = model.policyNumber;

            EslClient client = new EslClient(API_KEY, BASE_URL);
		
//replace DOC_FILE_PATH with your own value
            FileStream fs = File.OpenRead("path_to_pdf");

            // Build the DocumentPackage object
            DocumentPackage documentPackage = PackageBuilder.NewPackageNamed("C# Form Package " + DateTime.Now)

                // Customize package settings
                .WithSettings(DocumentPackageSettingsBuilder.NewDocumentPackageSettings()
                                .WithDecline()
                                .WithOptOut()
                                .WithDocumentToolbarDownloadButton()

                                // Customize the signing ceremony settings
                                .WithCeremonyLayoutSettings(CeremonyLayoutSettingsBuilder.NewCeremonyLayoutSettings()
                                        .WithoutGlobalNavigation()
                                        .WithoutBreadCrumbs()
                                        .WithoutSessionBar()
                                        .WithTitle()))

                // Define the insured first and last name
                .WithSigner(SignerBuilder.NewSignerWithEmail(emailAddress)
                                         .WithCustomId(CUSTOM_ID)
                                         .WithFirstName(firstName)
                                         .WithLastName(lastName)
                                         .WithCompany(company))

                // Define sender
                .WithSigner(SignerBuilder.NewSignerWithEmail("something@gmail.com")
                                         .WithCustomId("Sender")
                                         .WithFirstName("Haris")
                                         .WithLastName("Haidary")
                                         .WithTitle("Technical Evangelist")
                                         .WithCompany("eSignLive"))

                // Define the document
                .WithDocument(DocumentBuilder.NewDocumentNamed("Form")
                                    .FromStream(fs, DocumentType.PDF)
                                    .EnableExtraction()
                                    .WithInjectedField(FieldBuilder.TextField()
                                        .WithName("first_name")
                                        .WithValue(firstName))
                                    .WithInjectedField(FieldBuilder.TextField()
                                        .WithName("last_name")
                                        .WithValue(lastName))
                                    .WithInjectedField(FieldBuilder.TextField()
                                        .WithName("address")
                                        .WithValue(address))
                                    .WithInjectedField(FieldBuilder.TextField()
                                        .WithName("city")
                                        .WithValue(city))
                                    .WithInjectedField(FieldBuilder.TextField()
                                        .WithName("state")
                                        .WithValue(state))
                                    .WithInjectedField(FieldBuilder.TextField()
                                        .WithName("zip")
                                        .WithValue(zip))
                                    .WithInjectedField(FieldBuilder.TextField()
                                        .WithName("country")
                                        .WithValue(country))
                                    .WithInjectedField(FieldBuilder.TextField()
                                        .WithName("phone_number")
                                        .WithValue(phone))
                                    .WithInjectedField(FieldBuilder.TextField()
                                        .WithName("company")
                                        .WithValue(company))
                                    .WithInjectedField(FieldBuilder.TextField()
                                        .WithName("email")
                                        .WithValue(emailAddress))
                                    .WithInjectedField(FieldBuilder.TextField()
                                        .WithName("policy_number")
                                        .WithValue(policyNumber))

            ).Build();

            // Issue the request to the e-SignLive server to create the DocumentPackage
            PackageId packageId = client.CreatePackage(documentPackage);
            client.SendPackage(packageId);

            return packageId;
        }

        public static SessionToken createSessionToken(PackageId packageId, string API_KEY, string BASE_URL)
        {
            EslClient client = new EslClient(API_KEY, BASE_URL);

            SessionToken sessionToken = client.SessionService.CreateSignerSessionToken(packageId, CUSTOM_ID);
            Trace.WriteLine("Session token: " + sessionToken.Token);

            return sessionToken;
        }
    }
}